- Inheritance
-
- Object
- PlatformInterface
- FlutterKycQitechPlatform
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion()
→ Future<String?>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
startDeviceScan(String token, String documentNumber, String sessionId, String eventId, String eventType, String environment)
→ Future<String?>
-
-
startFaceRecon(String environment, String clientSessionKey, {String? sessionId, String? documentNumber, String? fontColor, String? backgroundColor, String? fontFamily, bool? showIntroductionScreens, bool? showSuccessScreen, bool? showInvalidTokenScreen, String? audioConfiguration, String? onboardingTitle, String? onboardingFirstLabel, String? onboardingSecondLabel, String? onboardingThirdLabel, String? logLevel})
→ Future<FaceReconReturnValues>
-
-
startOcr(String environment, String mobileToken, String document, {String? sessionId, String? fontColor, String? backgroundColor, String? fontFamily, bool? showIntroductionScreens, bool? showSuccessScreen, String? onboardingTitle, String? onboardingFirstLabel, String? onboardingSecondLabel, String? onboardingThirdLabel, String? logLevel})
→ Future<OcrReturnValues>
-
-
toString()
→ String
-
A string representation of this object.
inherited